@@ -31,6 +31,7 @@
 #' @param minMax Whether to use [min,max] instead of [p25,p75] for nonnormal variables. The default is FALSE.
 #' @param showpm Logical, show normal distributed continuous variables as Mean ± SD. Default: T
 #' @param addOverall (optional, only used if strata are supplied) Adds an overall column to the table. Smd and p-value calculations are performed using only the stratifed clolumns. Default: F
+#' @param pairwise (optional, only used if strata are supplied) When there are three or more strata, it displays the p-values for pairwise comparisons. Default: F
 #' @return A matrix object containing what you see is also invisibly returned. This can be assinged a name and exported via write.csv.
 #' @details DETAILS
 #' @examples
@@ -40,7 +41,8 @@
 #' @importFrom data.table data.table := setkey
 #' @importFrom tableone CreateTableOne
 #' @importFrom labelled var_label var_label<-
-#' @importFrom stats chisq.test fisher.test kruskal.test oneway.test
+#' @importFrom stats chisq.test fisher.test kruskal.test oneway.test t.test wilcox.test
+#' @importFrom utils combn
 #' @importFrom methods is
 #' @export
 
@@ -50,7 +52,7 @@ CreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, test
                             testNormal = oneway.test, argsNormal = list(var.equal = F),
                             testNonNormal = kruskal.test, argsNonNormal = list(NULL),
                             showAllLevels = T, printToggle = F, quote = F, smd = F, Labels = F, exact = NULL, nonnormal = NULL,
-                            catDigits = 1, contDigits = 2, pDigits = 3, labeldata = NULL, minMax = F, showpm = T, addOverall = F) {
+                            catDigits = 1, contDigits = 2, pDigits = 3, labeldata = NULL, minMax = F, showpm = T, addOverall = F, pairwise = F) {
   setkey <- variable <- level <- . <- val_label <- NULL
 
   if (length(strata) != 1) {
@@ -141,6 +143,97 @@ CreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, test
     # cap.tb1 = paste("Table 1: Stratified by ", labeldata[variable == strata, "var_label"][1], sep="")
   }
 
+  if (pairwise && length(unique(data[[strata]])) > 2) {
+    # 정규성 테스트 수행
+    normality_results <- sapply(vars, function(x) {
+      is_continuous <- is.numeric(data[[x]]) || is.integer(data[[x]])
+      if (is_continuous && nrow(data) <= 5000) {
+        shapiro_test_result <- tryCatch(stats::shapiro.test(data[[x]])$p.value, error = function(e) NA)
+        return(!is.na(shapiro_test_result) && shapiro_test_result >= 0.05) # p >= 0.05면 정규성 만족
+      } else {
+        return(TRUE) # 큰 샘플이거나 정규성 검사가 불가할 때는 정규성 만족으로 처리
+      }
+    })
+
+    p_position <- which(colnames(ptb1) == "p")
+    strata_count <- length(unique(data$variables[[strata]]))
+    comparison_columns <- colnames(ptb1)[(p_position - strata_count):(p_position - 1)]
+    pairwise_comparisons <- combn(
+      comparison_columns, 2,
+      simplify = FALSE
+    )
+    pairwise_pvalues_list <- lapply(vars, function(x) {
+      sapply(pairwise_comparisons, function(pair) {
+        subset_data <- data[data[[strata]] %in% pair, ]
+        is_continuous <- is.numeric(data[[x]]) || is.integer(data[[x]])
+        test_result <- if (is_continuous) {
+          if (normality_results[x]) {
+            tryCatch(
+              {
+                test <- t.test(subset_data[[x]] ~ subset_data[[strata]], var.equal = FALSE) # Welch's t-test
+                list(p_value = test$p.value, test_used = "t-test")
+              },
+              error = function(e) {
+                list(p_value = NA, test_used = NA)
+              }
+            )
+          } else {
+            tryCatch(
+              {
+                test <- wilcox.test(subset_data[[x]] ~ subset_data[[strata]])
+                list(p_value = test$p.value, test_used = "wilcox")
+              },
+              error = function(e) {
+                list(p_value = NA, test_used = NA)
+              }
+            )
+          }
+        } else {
+          # 범주형 데이터에 대해 Chi-square 또는 Fisher's exact test 수행
+          tryCatch(
+            {
+              test <- chisq.test(table(subset_data[[strata]], subset_data[[x]]))
+              list(p_value = test$p.value, test_used = "chisq")
+            },
+            warning = function(w) {
+              test <- fisher.test(table(subset_data[[strata]], subset_data[[x]]))
+              list(p_value = test$p.value, test_used = "exact")
+            },
+            error = function(e) {
+              list(p_value = NA, test_used = NA)
+            }
+          )
+        }
+        return(test_result)
+      }, simplify = FALSE)
+    })
+    names(pairwise_pvalues_list) <- vars
+
+    for (i in seq_along(pairwise_comparisons)) {
+      col_name <- paste0("p(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
+      test_name <- paste0("test(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
+      ptb1 <- cbind(ptb1, col_name = "", test_name = "")
+      colnames(ptb1)[ncol(ptb1) - 1] <- col_name
+      colnames(ptb1)[ncol(ptb1)] <- test_name
+    }
+
+    for (i in seq_along(pairwise_comparisons)) {
+      col_name <- paste0("p(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
+      test_name <- paste0("test(", pairwise_comparisons[[i]][1], "vs", pairwise_comparisons[[i]][2], ")")
+      for (x in vars) {
+        p_value <- pairwise_pvalues_list[[x]][[i]]$p_value
+        test_used <- pairwise_pvalues_list[[x]][[i]]$test_used
+        cleaned_row_names <- gsub("\\s+|\\(\\%\\)", "", rownames(ptb1))
+        cleaned_var_name <- gsub("\\s+|\\(\\%\\)", "", x)
+        first_row <- which(cleaned_row_names == cleaned_var_name)[1]
+        p_value <- ifelse(p_value < 0.001, "<0.001", as.character(round(p_value, 2)))
+        ptb1[first_row, col_name] <- p_value
+        ptb1[first_row, test_name] <- test_used
+      }
+    }
+    cols_to_remove <- grep("^test\\(", colnames(ptb1))
+    ptb1 <- ptb1[, -cols_to_remove]
+  }
   sig <- ifelse(ptb1[, "p"] == "<0.001", "0", ptb1[, "p"])
   sig <- as.numeric(as.vector(sig))
   sig <- ifelse(sig <= 0.05, "**", "")
@@ -183,7 +276,7 @@ CreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, test
 #' @param showpm Logical, show normal distributed continuous variables as Mean ± SD. Default: T
 #' @param addOverall (optional, only used if strata are supplied) Adds an overall column to the table. Smd and p-value calculations are performed using only the stratifed clolumns. Default: F
 #' @param normalityTest Logical, perform the Shapiro test for all variables. Default: F
-#' @return A matrix object containing what you see is also invisibly returned. This can be assinged a name and exported via write.csv.
+#' @param pairwise (optional, only used if strata are supplied) When there are three or more strata, it displays the p-values for pairwise comparisons. Default: F#' @return A matrix object containing what you see is also invisibly returned. This can be assinged a name and exported via write.csv.
 #' @details DETAILS
 #' @examples
 #' library(survival)
@@ -204,7 +297,7 @@ CreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, factorVa
                              testNonNormal = kruskal.test, argsNonNormal = list(NULL),
                              showAllLevels = T, printToggle = F, quote = F, smd = F, Labels = F, exact = NULL, nonnormal = NULL,
                              catDigits = 1, contDigits = 2, pDigits = 3, labeldata = NULL, psub = T, minMax = F, showpm = T,
-                             addOverall = F, normalityTest = F) {
+                             addOverall = F, normalityTest = F, pairwise = F) {
   . <- level <- variable <- val_label <- V1 <- V2 <- NULL
   # if (Labels & !is.null(labeldata)){
   #  var_label(data) = sapply(names(data), function(v){as.character(labeldata[get("variable") == v, "var_label"][1])}, simplify = F)
@@ -279,10 +372,9 @@ CreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, factorVa
       testNormal = testNormal, argsNormal = argsNormal,
       testNonNormal = testNonNormal, argsNonNormal = argsNonNormal, smd = smd,
       showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, Labels = Labels, nonnormal = nonnormal, exact = exact,
-      catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, labeldata = labeldata, minMax = minMax, showpm = showpm, addOverall = addOverall
+      catDigits = catDigits, contDigits = contDigits, pDigits = pDigits, labeldata = labeldata, minMax = minMax, showpm = showpm, addOverall = addOverall, pairwise = pairwise
     )
 
-
     cap.tb1 <- paste("Stratified by ", strata, sep = "")
 
     if (Labels & !is.null(labeldata)) {
